@@ -2,12 +2,12 @@ from pprint import pprint
 
 from matplotlib import pyplot as plt
 
-from examples.datasets.linear import LinearClassificationDataset
-from pytolemaic.pytrust import PyTrust
 ## For this example we create train/test data representing a linear function
 # both numpy and pandas.DataFrame is ok.
-from pytolemaic.utils.dmd import DMD
-from pytolemaic.utils.metrics import Metrics
+from pytolemaic import DMD
+from pytolemaic import Metrics
+from pytolemaic import PyTrust
+from resources.datasets.linear import LinearClassificationDataset
 
 
 def run():
@@ -45,7 +45,7 @@ def run():
         metric=metric,
         splitter=splitter)
 
-    scoring_report = pytrust.create_scoring_report()
+    scoring_report = pytrust.scoring_report
 
     score_value = scoring_report.metric_scores[metric].value
     ci_low = scoring_report.metric_scores[metric].ci_low
