@@ -1,5 +1,6 @@
 import itertools
 
+import numpy
 from matplotlib import pyplot as plt
 
 from pytolemaic.utils.base_report import Report
@@ -270,7 +271,12 @@ class DatasetAnalysisReport(Report):
             if len(class_counts) == 1:
                 list_of_classes = ": " + list_of_classes[0]
             else:
-                list_of_classes = ". List of classes:\n\t" + ",\n\t".join(list_of_classes)
+                n_lines_to_show = 5
+                if len(list_of_classes) > n_lines_to_show:
+                    suffix = '\n\t... {} more.'.format(len(list_of_classes) - n_lines_to_show)
+                else:
+                    suffix = ''
+                list_of_classes = ". List of classes:\n\t" + ",\n\t".join(list_of_classes[:n_lines_to_show]) + suffix
 
             insights.append("{}{}".format(sentence, list_of_classes))
 
@@ -289,6 +295,12 @@ class DatasetAnalysisReport(Report):
                 .format(feature_name, n_sigma_info['n_outliers'], n_sigma_range, max_n_sigma)
             insights.append(sentence)
 
+            log10_plus_one = numpy.log10(numpy.round(n_sigma_info['max'] + 1))
+
+            if n_sigma_info['max'] >= 99 and log10_plus_one == int(log10_plus_one):
+                insights.append("Feature '{}' has a maximal value of {} which doesn't seem to be a legit value".format(
+                    feature_name, n_sigma_info['max']))
+
         return self._add_cls_name_prefix(insights)
 
     def insights(self):
