@@ -16,7 +16,7 @@ from pytolemaic.utils.metrics import Metrics
 
 class ROCCurveReport(Report):
     def __init__(self, y_true, y_proba, labels=None, sample_weight=None):
-        self._labels = labels if labels is not None else unique_labels(y_true)
+        self._labels = labels if labels is not None else unique_labels(y_true).tolist()
         self._roc_curve = {}
         self._auc = {}
         for class_index, label in enumerate(self.labels):
@@ -42,7 +42,7 @@ class ROCCurveReport(Report):
     def to_dict(self, printable=False):
         out = dict(roc_curve=self.roc_curve,
                     auc=self.auc,
-                    labels=self.labels.tolist())
+                    labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -62,7 +62,7 @@ class ROCCurveReport(Report):
         for class_index, label in enumerate(self.labels):
             fpr, tpr = self._roc_curve[label]['fpr'], self._roc_curve[label]['tpr']
             roc_auc = self.auc[label]
-            viz = RocCurveDisplay(fpr, tpr, roc_auc, 'Classifier')
+            viz = RocCurveDisplay(fpr=fpr, tpr=tpr, roc_auc=roc_auc, estimator_name='Classifier')
 
             viz.plot(ax=ax, name=label, color=possible_colors[class_index])
 
@@ -87,7 +87,7 @@ class ROCCurveReport(Report):
 
 class PrecisionRecallCurveReport(Report):
     def __init__(self, y_true, y_proba, labels=None, sample_weight=None):
-        self._labels = labels if labels is not None else unique_labels(y_true)
+        self._labels = labels if labels is not None else unique_labels(y_true).tolist().tolist()
         self._recall_precision_curve = {}
         self._average_precision = {}
         for class_index, label in enumerate(self.labels):
@@ -114,7 +114,7 @@ class PrecisionRecallCurveReport(Report):
     def to_dict(self, printable=False):
         out = dict(recall_precision_curve=self.recall_precision_curve,
                     average_precision=self.average_precision,
-                    labels=self.labels.tolist())
+                    labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -136,8 +136,9 @@ class PrecisionRecallCurveReport(Report):
             recall = self._recall_precision_curve[label]['recall']
             average_precision = self._average_precision[label]
 
-            viz = PrecisionRecallDisplay(precision, recall, average_precision,
-                                         'Classifier')
+            viz = PrecisionRecallDisplay(precision=precision, recall=recall, average_precision=average_precision,
+                                         estimator_name='Classifier')
+
             viz.plot(ax=ax, name=label, color=possible_colors[class_index])
 
     def insights(self):
@@ -147,7 +148,7 @@ class PrecisionRecallCurveReport(Report):
 class CalibrationCurveReport(Report):
     def __init__(self, y_true, y_proba, labels=None, sample_weight=None,
                  n_bins=10):
-        self._labels = labels if labels is not None else unique_labels(y_true)
+        self._labels = labels if labels is not None else unique_labels(y_true).tolist()
         self._calibration_curve = {}
         self._brier_loss = {}
         self._y_proba = y_proba
@@ -185,7 +186,7 @@ class CalibrationCurveReport(Report):
     def to_dict(self, printable=False):
         out = dict(calibration_curve=self.calibration_curve,
                    brier_loss=self.brier_loss,
-                   labels=self.labels.tolist())
+                   labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -263,7 +264,7 @@ class SklearnClassificationReport(Report):
     def __init__(self, y_true, y_pred, y_proba, labels=None,
                  sample_weight=None, digits=3):
         self._labels = labels if labels is not None else unique_labels(y_true,
-                                                                       y_pred)
+                                                                       y_pred).tolist()
 
         self._sample_weight = sample_weight
 
@@ -322,7 +323,7 @@ class SklearnClassificationReport(Report):
             roc_curve=self.roc_curve.to_dict(),
             precision_recall_curve=self.precision_recall_curve.to_dict(),
             calibration_curve=self.calibration_curve.to_dict(),
-            labels=self.labels.tolist())
+            labels=self.labels)
         return self._printable_dict(out, printable=printable)
 
     @classmethod
@@ -395,13 +396,15 @@ class SklearnClassificationReport(Report):
 
 
 class ConfusionMatrixReport(Report):
-    def __init__(self, y_true, y_pred, labels=None):
+    def __init__(self, y_true, y_pred, labels: list = None):
         self._confusion_matrix = confusion_matrix(y_true=y_true, y_pred=y_pred,
                                                   labels=unique_labels(y_true, y_pred)).tolist()
-        self._labels = labels if labels is not None else unique_labels(y_true, y_pred)
+        self._labels = labels if labels is not None else unique_labels(y_true, y_pred).tolist()
+        if isinstance(self._labels, numpy.ndarray):
+            self._labels = self._labels.tolist()
 
     @property
-    def labels(self):
+    def labels(self)->list:
         return self._labels
 
     @property
@@ -430,7 +433,7 @@ class ConfusionMatrixReport(Report):
             )
 
     @classmethod
-    def _plot_confusion_matrix(cls, confusion_matrix, labels, title,
+    def _plot_confusion_matrix(cls, confusion_matrix, labels: list, title,
                                ax, cmap=plt.cm.Greens):
 
         cm = numpy.array(confusion_matrix)
@@ -440,7 +443,8 @@ class ConfusionMatrixReport(Report):
 
         ax.set(xticks=[-0.5] + numpy.arange(cm.shape[1]).tolist() + [cm.shape[1] - 0.5],
                yticks=[-0.5] + numpy.arange(cm.shape[0]).tolist() + [cm.shape[0] - 0.5],
-               xticklabels=[''] + labels.tolist(), yticklabels=[''] + labels.tolist(),
+               xticklabels=[''] + labels + [''],
+               yticklabels=[''] + labels + [''],
                title=title,
                ylabel='True labels',
                xlabel='Predicted labels')
@@ -653,8 +657,11 @@ class ScoringMetricReport(Report):
         ci_low = Metrics.metric_as_loss(value=self.ci_low, metric=self.metric)
         ci_high = Metrics.metric_as_loss(value=self.ci_high, metric=self.metric)
 
-        ci_ratio = abs(ci_high - ci_low) / (ci_high + ci_low) * 2
-        return ci_ratio
+        if ci_low == ci_high:
+            return 0
+        else:
+            ci_ratio = abs(ci_high - ci_low) / (ci_high + ci_low) * 2
+            return ci_ratio
 
 
 class ScoringFullReport(Report):
