@@ -76,7 +76,7 @@ class SensitivityAnalysis():
         for i, name in enumerate(dmd_test.feature_names):
             if dmd_test.n_samples > self.max_samples_to_use:
                 rs = numpy.random.RandomState(i)
-                subset = rs.permutation(self.max_samples_to_use)
+                subset = rs.permutation(dmd_test.n_samples)[:self.max_samples_to_use]
                 dmd_test_ = dmd_test.split_by_indices(subset)
                 y_pred_ = y_pred[subset]
             else:
@@ -197,7 +197,8 @@ class SensitivityAnalysis():
         score = np.mean(deltas) / max(deltas)
         return score
 
-    def calculate_sensitivity(self, model, dmd_test: DMD, metric: str, dmd_train=None):
+    def calculate_sensitivity(self, model, dmd_test: DMD, metric: str, dmd_train=None, **kwargs):
+        dmd_test = dmd_test or dmd_train
         self.shuffled_sensitivity = self.sensitivity_analysis(
             model=model,
             dmd_train=dmd_train,
@@ -221,7 +222,7 @@ class SensitivityAnalysis():
 
             self.missing_sensitivity = None
 
-    def sensitivity_report(self) -> SensitivityFullReport:
+    def sensitivity_report(self, **kwargs) -> SensitivityFullReport:
 
         vulnerability_report = self._vulnerability_report(
             shuffled_sensitivity=self.shuffled_sensitivity,
