@@ -5,6 +5,7 @@ import numpy
 import numpy as np
 import pandas
 from sklearn.model_selection import train_test_split
+from sklearn.preprocessing import LabelEncoder
 
 from pytolemaic.utils.constants import FeatureTypes
 
@@ -33,17 +34,18 @@ class StratifiedSplitter():
         return train, test
 
 
+
 class DMD():
     FEATURE_NAMES = '__FEATURE_NAMES__'
     FEATURE_TYPES = '__FEATURE_TYPES__'
     INDEX = '__INDEX__'
-    CATEGOICAL_ENCODING = 'CATEGOICAL_ENCODING'
+    CATEGOICAL_ENCODING = '__CATEGOICAL_ENCODING__'
 
     # SAMPLE_WEIGHTS = '__SAMPLE_WEIGHTS__'
 
-    def __init__(self, x, y=None, columns_meta=None, samples_meta=None,
-                 splitter=ShuffleSplitter, labels=None, categorical_encoding=None,
-                 feature_names=None, feature_types=None):
+    def __init__(self, x, y=None, columns_meta: dict = None, samples_meta: dict = None,
+                 splitter=ShuffleSplitter, target_labels: dict = None, categorical_encoding: dict = None,
+                 feature_names: list = None, feature_types: list = None):
 
         if (feature_names or feature_types) and not columns_meta:
             columns_meta = {}
@@ -64,11 +66,14 @@ class DMD():
         self._splitter = splitter
 
         # meta data
-        if labels is not None:
-            if self._y.values.max() >= len(labels):
+        if target_labels is not None:
+            if self._y.values.max() >= len(target_labels):
                 raise ValueError("Labels should be given to all classes")
 
-        self._labels = labels
+        if isinstance(target_labels, list):
+            target_labels = {i: cls_ for i, cls_ in enumerate(target_labels)}
+
+        self._target_encoding = target_labels
 
         self._categorical_encoding_by_name = categorical_encoding or {}
         self._categorical_encoding_by_ind = self._validate_categorical_encoding()
@@ -85,7 +90,7 @@ class DMD():
                 "When setting categorical_encoding you must also specify which feature is categorical through columns_meta")
 
         feature_names = self.feature_names
-        values = self.values
+        values = self.values.astype(float, copy=False)
         for icol in categorical_features:
             if feature_names[icol] not in categorical_encoding:
                 raise ValueError("No categorical names are set for feature #{}:{}".format(icol, feature_names[icol]))
@@ -142,7 +147,9 @@ class DMD():
                    columns_meta=copy.deepcopy(self._columns_meta),
                    samples_meta=copy.deepcopy(
                        self._samples_meta.iloc[indices, :]),
-                   splitter=self.splitter)
+                   splitter=self.splitter,
+                   target_labels=self.target_encoding,
+                   categorical_encoding=self.categorical_encoding_by_feature_name)
 
     def split(self, ratio, return_indices=False):
 
@@ -220,15 +227,28 @@ class DMD():
         if self._y is None:
             return None
         else:
-            return self._y.values.reshape(-1, 1)
+            return self._y.values
 
     @property
     def splitter(self):
         return self._splitter
 
     @property
-    def labels(self):
-        return self._labels
+    def target_encoding(self) -> dict:
+        return self._target_encoding  # {index: cls_}
+
+    @property
+    def labels(self) -> list:
+        """
+        :return: class names ordered by encoding.
+        """
+        if self.target_encoding is None:
+            return None
+
+        encoding = self._target_encoding  # {index: cls_}
+        inv_encoding = {cls_: index for index, cls_ in encoding.items()}
+        labels = sorted(inv_encoding.keys(), key=lambda cls_: inv_encoding[cls_])
+        return labels
 
     @property
     def categorical_features(self):
@@ -248,4 +268,104 @@ class DMD():
 
     @property
     def nan_mask(self):
-        return self._x.isnull().values
\ No newline at end of file
+        return self._x.isnull().values
+
+    @classmethod
+    def from_df(cls, df_train: pandas.DataFrame, target_name: str, is_classification, feature_types: list = None,
+                df_test: pandas.DataFrame = None,
+                categorical_encoding=False, split_ratio: float = None, nan_list: list = (), splitter=ShuffleSplitter):
+        feature_names = list(df_train.columns)
+        feature_names.remove(target_name)
+
+        categorical_encoding_dict = None
+        target_labels = None
+        if categorical_encoding:
+            if feature_types is None:
+                raise ValueError("categorical_encoding requires feature types")
+            logging.info("Categorical Encoding")
+            # fit
+            jibrish_value = '!@#$%^&*()'
+            df_train = copy.deepcopy(df_train)
+            for k in nan_list:
+                df_train.replace(k, numpy.nan, inplace=True)
+
+            nan_mask = df_train.isnull()
+            # df_train[nan_mask] = jibrish_value
+            df_train.replace(numpy.nan, jibrish_value, inplace=True)
+
+            xencoders = []
+            categorical_encoding_dict = {}
+            for i, feature_name in enumerate(feature_names):
+                logging.info("Fit encoding for feature {}".format(feature_name))
+
+                if feature_types[i] == FeatureTypes.categorical:
+                    le = LabelEncoder().fit(df_train[feature_name].astype(str))
+                    xencoders.append(le)
+                    categorical_encoding_dict[feature_name] = {i: cls_ for i, cls_ in enumerate(le.classes_)}
+                else:
+                    xencoders.append(None)
+
+            if is_classification:
+                yencoder = LabelEncoder().fit(df_train[target_name].astype(str))
+                target_labels = {i: cls_ for i, cls_ in enumerate(yencoder.classes_)}
+            else:
+                yencoder = None
+                target_labels = None
+
+            # transform train
+            for i, feature_name in enumerate(feature_names):
+                if feature_types[i] == FeatureTypes.categorical:
+                    logging.info("Encode train: feature {}".format(feature_name))
+                    df_train[feature_name] = xencoders[i].transform(df_train[feature_name].astype(str))
+
+            if yencoder:
+                df_train[target_name] = yencoder.transform(df_train[target_name].astype(str))
+
+            df_train[nan_mask] = numpy.nan
+
+            if df_test is not None:
+                df_test = copy.deepcopy(df_test)
+                for k in nan_list:
+                    df_test.replace(k, numpy.nan, inplace=True)
+
+                nan_mask = df_test.isnull()
+                df_test.replace(numpy.nan, jibrish_value, inplace=True)
+
+                for i, feature_name in enumerate(feature_names):
+                    if feature_types[i] == FeatureTypes.categorical:
+                        logging.info("Encode test: feature {}".format(feature_name))
+
+                        try:
+                            df_test[feature_name] = xencoders[i].transform(df_test[feature_name].astype(str))
+                        except ValueError as e:
+                            logging.warning(e)
+                            classes = xencoders[i].classes_
+                            mask = numpy.array([x in classes for x in df_test[feature_name].astype(str)])
+
+                            new_values = numpy.zeros(mask.shape)
+                            new_values[mask] = xencoders[i].transform(df_test[feature_name].astype(str)[mask])
+                            new_values[~mask] = -1
+                            df_test[feature_name] = new_values
+
+                if yencoder:
+                    df_test[target_name] = yencoder.transform(df_test[target_name].astype(str))
+
+                df_test[nan_mask] = numpy.nan
+
+        logging.info("Creating DMDs")
+
+        dmd_train = DMD(x=df_train[feature_names], y=df_train[target_name], splitter=splitter,
+                        target_labels=target_labels, categorical_encoding=categorical_encoding_dict,
+                        feature_names=feature_names, feature_types=feature_types)
+        if df_test is None:
+            if split_ratio is None:
+                dmd_test = None
+            else:
+                dmd_train, dmd_test = dmd_train.split(ratio=split_ratio)
+        else:
+
+            dmd_test = DMD(x=df_test[feature_names], y=df_test[target_name], splitter=splitter,
+                           target_labels=target_labels, categorical_encoding=categorical_encoding_dict,
+                           feature_names=feature_names, feature_types=feature_types)
+
+        return dmd_train, dmd_test
